@@ -17,7 +17,7 @@ module Specinfra
           @base_image = get_or_pull_image(image)
 
           create_and_start_container
-          ObjectSpace.define_finalizer(self, proc { cleanup_container })
+          ObjectSpace.define_finalizer(self, self.class.__send__(:finalizer_for, @container))
         elsif container = get_config(:docker_container)
           @container = ::Docker::Container.get(container)
         else
@@ -25,6 +25,25 @@ module Specinfra
         end
       end
 
+      class << self
+        protected
+
+        # Get a finalizer for given container.
+        #
+        # @param [::Docker::Container, nil] container
+        #
+        # @return [Proc]
+        def finalizer_for(container)
+          proc do
+            # noinspection RubyNilAnalysis
+            unless container.nil?
+              container.stop
+              container.delete
+            end
+          end
+        end
+      end
+
       def run_command(cmd, opts={})
         cmd = build_command(cmd)
         run_pre_command(opts)
@@ -77,8 +96,7 @@ module Specinfra
       end
 
       def cleanup_container
-        @container.stop
-        @container.delete
+        self.class.__send__(:finalizer_for, @container).call
       end
 
       def current_image
