@@ -6,6 +6,10 @@ module Specinfra
           def check_is_running_under_runit(service)
             "sv status #{escape(service)} | grep -E '^run: '"
           end
+
+          def check_is_enabled_under_runit(service)
+            "test ! -f /etc/sv/#{escape(service)}/down"
+          end
         end
       end
     end
